"""
Copyright 2008-2014 by Aerospike, Inc. All rights reserved.
THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE. THE COPYRIGHT NOTICE
ABOVE DOES NOT EVIDENCE ANY ACTUAL OR INTENDED PUBLICATION.
"""


# -*- coding: utf-8 -*-
from helpers import convertor


def get_info(cluster_obj, node_list, xdr_port):

    info = dict()
    node_list = node_list.replace(' ', '')
    node_list = convertor.text_to_list(node_list, ',')

    for node_address in node_list:
        node_obj = cluster_obj.get_node(node_address)
        info[node_address] = dict()
        xdr_obj = None
        if node_obj is None or not node_obj.is_valid():
            info[node_address]['node_status'] = "off"
            info[node_address]['xdr_status'] = "off"
        elif node_obj.get_status() == "off":
            info[node_address]['node_status'] = "off"
            xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)
        else:
            info[node_address]['node_status'] = "on"
            xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)

        if xdr_obj == {}:
            info[node_address]['xdr_status'] = "off"
        elif xdr_obj is not None:
            info[node_address]['xdr_status'] = "on"
            stats = xdr_obj.get_subset_of_statistics(['stat_recs_outstanding',
                'timediff_lastship_cur_secs', 'esmt-bytes-shipped',
                'stat_recs_relogged', 'stat_recs_shipped', 'free-dlog-pct',
                'xdr-uptime', 'cur_throughput'])
            info[node_address].update(stats)

    return info


def get_stats(cluster_obj, node_address, xdr_port, stats_type):

    #info = dict(address=node_address)
    info = dict()
    node_obj = cluster_obj.get_node(node_address)

    xdr_obj = None
    if node_obj is None or not node_obj.is_valid():
        info['node_status'] = "off"
        info['xdr_status'] = "off"
    elif node_obj.get_status() == "off":
        info['node_status'] = "off"
        xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)
    else:
        info['node_status'] = "on"
        xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)

    if xdr_obj == {}:
        info['xdr_status'] = "off"
    elif xdr_obj is not None:
        info['xdr_status'] = "on"
        stats = xdr_obj.get_statistics(stats_type)
        info.update(stats)
        configurations = xdr_obj.get_configurations(stats_type)
        info.update(configurations)

    return info


def get_all_config(cluster_obj, node_address, xdr_port):

    info = dict(address=node_address)
    node_obj = cluster_obj.get_node(node_address)

    xdr_obj = None
    if node_obj is None or not node_obj.is_valid():
        info['node_status'] = "off"
        info['xdr_status'] = "off"
    elif node_obj.get_status() == "off":
        info['node_status'] = "off"
        xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)
    else:
        info['node_status'] = "on"
        xdr_obj = cluster_obj.get_xdr(xdr_port, node_address)

    if xdr_obj == {}:
        info['xdr_status'] = "off"
    elif xdr_obj is not None:
        info['xdr_status'] = "on"
        configurations = xdr_obj.get_configurations()
        info.update(configurations)

    return info


def change_xdr_status(desired_status, cluster_obj, node_address, username="", password=None):

    info = dict(address=node_address)
    node_obj = cluster_obj.get_node(node_address)

    xdr_obj = None
    if node_obj is not None and node_obj.get_status() is not "off" and node_obj.is_valid() is True:
        xdr_obj = cluster_obj.get_xdr("3004", node_address)

    if xdr_obj is None:
        info['node_status'] = "off"
    elif xdr_obj == {} and desired_status == "off":
        info['status'] = "Failue"
        info['error'] = "XDR Already Off"
    elif xdr_obj is not None and xdr_obj != {} and desired_status == "on":
        info['status'] = "Failue"
        info['error'] = "XDR Already On"
    else:
        status = node_obj.change_xdr_status(desired_status, username, password)
        info.update(status)
    return info
