"""
Copyright 2008-2014 by Aerospike, Inc. All rights reserved.
THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE. THE COPYRIGHT NOTICE
ABOVE DOES NOT EVIDENCE ANY ACTUAL OR INTENDED PUBLICATION.
"""


# -*- coding: utf-8 -*-

import sqlite3
from helpers import encryption
from constants import SECRET_KEY, AMC_DB_PATH


class UserManager(object):

    _instance = None

    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            cls._instance = super(UserManager, cls).__new__(
                                cls, *args, **kwargs)
            cls._instance.__init__()
        return cls._instance

    def __init__(self):

        self._conn = sqlite3.connect('%s' % AMC_DB_PATH)
        self.initialize_db()

        #Create an admin user (username, password).  The password is stored
        #as a md5 hash that has also been salted.

        if not self.get_user('admin'):
            self.add_user('admin', encryption.hash_pass('admin', SECRET_KEY), 'ReadWrite')

    def initialize_db(self):

        c = self._conn.cursor()
        c.execute("""CREATE TABLE IF NOT EXISTS user(
            id INTEGER PRIMARY KEY,
            username TEXT,
            password TEXT,
            role TEXT)""")
        self._conn.commit()

    def add_user(self, username, password, role):

        c = self._conn.cursor()
        c.execute("""INSERT INTO user VALUES (null, ?, ?, ?)""",
            (username, password, role))
        self._conn.commit()

    def get_user(self, username):

        c = self._conn.cursor()
        c.execute("SELECT * FROM user WHERE username = ?", (username, ))
        return c.fetchone()

    def change_password(self, username, new_password):

        c = self._conn.cursor()
        c.execute("""UPDATE user set password = ? where username = ?""",
            (new_password, username))
        if c.rowcount == 0:
            return "failure"
        self._conn.commit()
        return "success"
